@@ -1,7 +1,7 @@
+pub(crate) mod foreign_key;
+pub(crate) mod index;
 pub(crate) mod query;
 pub(crate) mod table;
-pub(crate) mod index;
-pub(crate) mod foreign_key;
 
 use super::*;
 
@@ -9,15 +9,16 @@ use super::*;
 #[derive(Debug)]
 pub struct MysqlQueryBuilder;
 
+pub type MySqlQueryBuilder = MysqlQueryBuilder;
+
 impl Default for MysqlQueryBuilder {
     fn default() -> Self {
         Self
     }
 }
 
-impl GenericBuilder for MysqlQueryBuilder {
-    type QueryBuilder = Self;
-    type TableBuilder = Self;
-    type IndexBuilder = Self;
-    type ForeignKeyBuilder = Self;
-}
\ No newline at end of file
+impl GenericBuilder for MysqlQueryBuilder {}
+
+impl SchemaBuilder for MysqlQueryBuilder {}
+
+impl QuotedBuilder for MysqlQueryBuilder {}
